# CPR Simulator

This package contains the retirement simulator developed by the [Retirement and Savings Institute (RSI)](http://ire.hec.ca/en/). It is available on [pip](https://pypi.org/project/cpr-rsi/). The [documentation](https://rsi-models.github.io/CPR/en) describes the model and its uses.
